==> compaqt-0.4.1.tar.gz: compaqt-0.4.1/tests/test_values.py <==
# A list of all values to test

test_values = [
    0,
    1,
    -1,
    123456789,
    -123456789,
    2**31 - 1,
    -(2**31),
    2**63 - 1,
    -(2**63),
    2**40,
    -(2**40),
    9223372036854775807,
    -9223372036854775808,
    0.0,
    1.0,
    -1.0,
    1.23e5,
    -1.23e5,
    1.7e308,
    -1.7e308,
    5e-324,
    -5e-324,
    3.141592653589793,
    2.718281828459045,
    1.7976931348623157e+308,
    -1.7976931348623157e+308,
    "",
    "Hello, World!",
    "1234567890",
    "A"*100,
    "This is a test.",
    "Line 1\nLine 2\nLine 3",
    "Special characters: !@#$%^&*()",
    "Unicode: αβγδ",
    "Very long string: " + "A" * 1000,
    "Tab\tDelimited",
    "Escaped quotes: \"Hello!\"",
    "Café",
    "Mix of numbers and letters: a1b2c3",
    "A\0B\0C\0D\0E",
    b"",
    b"Hello, World!",
    bytes([65, 66, 67]),
    b"\x00\x01\x02\x03\x04",
    b"Special characters: !@#$%^&*()",
    b"Line 1\nLine 2\nLine 3",
    b"Unicode: \xe2\x9c\x94",
    b"Very long bytes: " + bytes([65] * 1000),
    b"\xFF\xFE\xFD\xFC",
    b"Tab\tDelimited",
    b"Escaped quotes: \"Hello!\"",
    b"Caf\xe9",
    bytes(range(256)),
    0 + 0j,
    2 + 3j,
    -1 - 1j,
    1.5 + 2.5j,
    3 + 0j,
    0 + 4j,
    1e10 + 2e10j,
    -1e-10 - 1e-10j,
    2j + 3,
    1 + 1j,
    [],
    [1, 2, 3],
    [1.1, 2.2, 3.3],
    ["apple", "banana", "cherry"],
    [True, False, True],
    [1, "two", 3.0, False],
    [[1, 2], [3, 4]],
    [1, 2j, "three", {"key": "value"}],
    {},
    {"key1": "value1", "key2": "value2"},
    {"a": 1, "b": 2, "c": 3},
    {"name": "Alice", "age": 30},
    {"nested": {"inner_key": "inner_value"}},
    {"boolean": True, "number": 42},
    {"list": [1, 2, 3], "complex": 2 + 3j},
    True,
    False,
    None,
    [True, False, None],
    {True: {False: None}},
]

==> compaqt-0.5.0.tar.gz: compaqt-0.5.0/tests/test_values.py <==
# A list of all values to test

test_values = [
    0,
    1,
    -1,
    123456789,
    -123456789,
    2**31 - 1,
    -(2**31),
    2**63 - 1,
    -(2**63),
    2**40,
    -(2**40),
    9223372036854775807,
    -9223372036854775808,
    0.0,
    1.0,
    -1.0,
    1.23e5,
    -1.23e5,
    1.7e308,
    -1.7e308,
    5e-324,
    -5e-324,
    3.141592653589793,
    2.718281828459045,
    1.7976931348623157e+308,
    -1.7976931348623157e+308,
    "",
    "Hello, World!",
    "1234567890",
    "This is a test.",
    "Line 1\nLine 2\nLine 3",
    "!@#$%^&*()",
    "Unicode: αβγδ",
    "Length mode 1: " + "A" * 64,
    "Length mode 2: " + "A" * 1024,
    "Tab\tDelimited",
    "Café",
    "a1b2c3",
    "A\0B\0C\0D\0E",
    b"",
    b"Hello, World!",
    bytes([65, 66, 67]),
    b"\x00\x01\x02\x03\x04",
    b"!@#$%^&*()",
    b"Line 1\nLine 2\nLine 3",
    b"Unicode: \xe2\x9c\x94",
    b"Length mode 1: " + bytes([65] * 64),
    b"Length mode 2: " + bytes([65] * 1024),
    b"\xFF\xFE\xFD\xFC",
    b"Tab\tDelimited",
    b"Caf\xe9",
    bytes(range(256)),
    [],
    [1, 2, 3],
    [1.1, 2.2, 3.3],
    ["apple", "banana", "cherry"],
    [True, False, True],
    [1, "two", 3.0, False],
    [[1, 2], [3, 4]],
    ["waow!", "three", {"key": "value"}],
    {},
    {"key1": "value1", "key2": "value2"},
    {"a": 1, "b": 2, "c": 3},
    {"name": "Alice", "age": 30},
    {"nested": {"inner_key": "inner_value"}},
    {"boolean": True, "number": 42},
    {"list": [1, 2, 3], "dict": {"Why": "Not"}},
    True,
    False,
    None,
    [True, False, None],
    {True: {False: None}},
]
